@@ -116,6 +116,7 @@
 #'  \item{cross_fitting_folds}{the folds used for cross-fitting}
 #'  \item{y}{the outcome}
 #'  \item{ipc_weights}{the weights}
+#'  \item{cluster_id}{the cluster IDs}
 #'  \item{mat}{a tibble with the estimate, SE, CI, hypothesis testing decision, and p-value}
 #' }
 #'
@@ -197,11 +198,17 @@ cv_vim <- function(Y = NULL, X = NULL, cross_fitted_f1 = NULL,
                    nuisance_estimators_full = NULL,
                    nuisance_estimators_reduced = NULL, exposure_name = NULL,
                    cross_fitted_se = TRUE, bootstrap = FALSE, b = 1000,
-                   boot_interval_type = "perc", ...) {
+                   boot_interval_type = "perc", clustered = FALSE,
+                   cluster_id = rep(NA, length(Y)), ...) {
     # check to see if f1 and f2 are missing
     # if the data is missing, stop and throw an error
     check_inputs(Y, X, cross_fitted_f1, cross_fitted_f2, indx)
 
+    if (bootstrap & clustered & sum(is.na(cluster_id)) > 0){
+      stop(paste0("If using clustered bootstrap, cluster IDs must be provided",
+                  " for all observations."))
+    }
+
     if (sample_splitting) {
         ss_V <- V * 2
     } else {
@@ -399,7 +406,9 @@ cv_vim <- function(Y = NULL, X = NULL, cross_fitted_f1 = NULL,
         se_redu <- NA
         if (bootstrap) {
             boot_results <- bootstrap_se(Y = Y_cc, f1 = non_cf_full_preds,
-                                         f2 = non_cf_redu_preds, type = full_type, b = b)
+                                         f2 = non_cf_redu_preds, type = full_type,
+                                         b = b, clustered = clustered,
+                                         cluster_id = cluster_id)
             se <- boot_results$se
         }
     } else {
@@ -500,7 +509,8 @@ cv_vim <- function(Y = NULL, X = NULL, cross_fitted_f1 = NULL,
             boot_results <- bootstrap_se(Y = Y_cc, f1 = non_cf_full_preds,
                                          f2 = non_cf_redu_preds, type = full_type,
                                          b = b, boot_interval_type = boot_interval_type,
-                                         alpha = alpha)
+                                         alpha = alpha, clustered = clustered,
+                                         cluster_id = cluster_id)
             se <- boot_results$se
             se_full <- boot_results$se_full
             se_redu <- boot_results$se_reduced
@@ -561,14 +571,18 @@ cv_vim <- function(Y = NULL, X = NULL, cross_fitted_f1 = NULL,
         # swap the roles of the folds
         full_test_for_est <- (k_fold_lst$sample_splitting_folds == 2)
         redu_test_for_est <- (k_fold_lst$sample_splitting_folds == 1)
+        cf_folds_full_for_est <- k_fold_lst$reduced
+        cf_folds_redu_for_est <- k_fold_lst$full
+        cf_folds_full_cc_for_est <- cf_folds_full_for_est[C[full_test_for_est] == 1]
+        cf_folds_redu_cc_for_est <- cf_folds_redu_for_est[C[redu_test_for_est] == 1]
         full_test_cc_for_est <- full_test_for_est[C == 1]
-        redu_test_cc_for_est <- full_test_for_est[C == 1]
+        redu_test_cc_for_est <- redu_test_for_est[C == 1]
         est_pred_full <- do.call(predictiveness_measure, c(
           list(type = full_type, y = Y_cc[full_test_cc_for_est], full_y = Y_cc,
                a = A_cc[full_test_cc_for_est], fitted_values = full_preds[full_test_cc_for_est],
-               cross_fitting_folds = cf_folds_full_cc, C = C[full_test_for_est],
+               cross_fitting_folds = cf_folds_full_cc_for_est, C = C[full_test_for_est],
                Z = Z_in[full_test_for_est, , drop = FALSE],
-               folds_Z = cf_folds_full, ipc_weights = ipc_weights[full_test],
+               folds_Z = cf_folds_full_for_est, ipc_weights = ipc_weights[full_test_for_est],
                ipc_fit_type = "SL", scale = ipc_scale, ipc_est_type = ipc_est_type,
                na.rm = na.rm, SL.library = SL.library, nuisance_estimators = lapply(
                  nuisance_estimators_full, function(l) {
@@ -579,9 +593,9 @@ cv_vim <- function(Y = NULL, X = NULL, cross_fitted_f1 = NULL,
         est_pred_reduced <- do.call(predictiveness_measure, c(
           list(type = full_type, y = Y_cc[redu_test_cc_for_est], full_y = Y_cc,
                a = A_cc[redu_test_cc_for_est], fitted_values = redu_preds[redu_test_cc_for_est],
-               cross_fitting_folds = cf_folds_redu_cc, C = C[redu_test],
+               cross_fitting_folds = cf_folds_redu_cc_for_est, C = C[redu_test_for_est],
                Z = Z_in[redu_test_for_est, , drop = FALSE],
-               folds_Z = cf_folds_redu, ipc_weights = ipc_weights[redu_test_for_est],
+               folds_Z = cf_folds_redu_for_est, ipc_weights = ipc_weights[redu_test_for_est],
                ipc_fit_type = "SL", scale = ipc_scale, ipc_est_type = ipc_est_type,
                na.rm = na.rm, SL.library = SL.library, nuisance_estimators = lapply(
                  nuisance_estimators_reduced, function(l) {
@@ -678,6 +692,7 @@ cv_vim <- function(Y = NULL, X = NULL, cross_fitted_f1 = NULL,
                    ipc_weights = ipc_weights,
                    ipc_scale = ipc_scale,
                    scale = scale,
+                   cluster_id = cluster_id,
                    mat = mat)
 
     # make it also a vim and vim_type object
