@@ -41,15 +41,17 @@ vimp_deviance <- function(Y = NULL, X = NULL, cross_fitted_f1 = NULL,
                           V = 10, run_regression = TRUE,
                           SL.library = c("SL.glmnet", "SL.xgboost", "SL.mean"),
                           alpha = 0.05, delta = 0, na.rm = FALSE,
+                          final_point_estimate = "split",
                           cross_fitting_folds = NULL, sample_splitting_folds = NULL,
                           stratified = TRUE, C = rep(1, length(Y)), Z = NULL,
-                          ipc_weights = rep(1, length(Y)), scale = "identity",
+                          ipc_weights = rep(1, length(Y)), scale = "logit",
                           ipc_est_type = "aipw", scale_est = TRUE,
                           cross_fitted_se = TRUE, ...) {
   cv_vim(type = "deviance", Y = Y, X = X, cross_fitted_f1 = cross_fitted_f1,
          cross_fitted_f2 = cross_fitted_f2, f1 = f1, f2 = f2, indx = indx,
          V = V, run_regression = run_regression, SL.library = SL.library,
          alpha = alpha, delta = delta, na.rm = na.rm, stratified = stratified,
+         final_point_estimate = final_point_estimate, 
          cross_fitting_folds = cross_fitting_folds, ipc_weights = ipc_weights,
          sample_splitting_folds = sample_splitting_folds, C = C, Z = Z,
          scale = scale, ipc_est_type = ipc_est_type, scale_est = scale_est,
